import LicenseSpring

import SwiftUI

struct ContentView: View {
    @State private var manager: LicenseManager?
    @State private var floatingClient: FloatingClient?
    @State private var managerType: ManagerType = .licenseManager
    @State private var configSheetPresented = true
    @State private var logs: [String] = []
    
    @EnvironmentObject private var viewUpdater: ViewUpdaterHack
    
    var body: some View {
        VStack {
            switch managerType {
            case .licenseManager:
                if let license = manager?.currentLicense {
                    LicenseView(manager: manager, license: license)
                } else {
                    InitialView(manager: manager, showConfiguration: $configSheetPresented)
                }
            case .floatingClient:
                if let license = floatingClient?.currentLicense {
                    LicenseView(manager: floatingClient, license: license)
                } else {
                    InitialFloatingClientView(manager: floatingClient, showConfiguration: $configSheetPresented)
                }
            }
            GroupBox(label: Text("Logs")) {
                ScrollView {
                    ForEach(logs, id: \.self) {
                        Text($0)
                            .frame(maxWidth: .infinity, alignment: .leading)
                    }
                }
                .frame(maxWidth: .infinity, maxHeight: 100)
            }
            .padding([.horizontal, .bottom])
            .onAppear {
                LSLog.log = { logs.append("[\($0.rawValue.uppercased())] \($1())") }
            }
        }
        .frame(width: size.width, height: size.height)
        .sheet(
            isPresented: $configSheetPresented,
            onDismiss: { configSheetPresented = manager == nil && floatingClient == nil
            }
        ) {
            ConfigView(managerType: $managerType) { config in
                guard let config else { exit(0) }
                switch managerType {
                case .licenseManager:
                    manager = try LicenseManager(configuration: config)
                case .floatingClient:
                    floatingClient = try FloatingClient(configuration: config)
                }
                configSheetPresented = false
            }
            .frame(minWidth: 500)
            .padding()
        }
    }
    
    private var size: CGSize {
        if manager?.currentLicense != nil || floatingClient?.currentLicense != nil {
            return CGSize(width: 1200, height: 800)
        } else {
            return CGSize(width: 800, height: 800)
        }
    }
}

struct ContentView_Previews: PreviewProvider {
    static var previews: some View {
        ContentView()
    }
}
